﻿using System;
using System.IO;
using System.Windows;
using Microsoft.Win32;

namespace ACSuite.Views
{
    public partial class FileInverter : Window
    {
        public FileInverter()
        {
            InitializeComponent();
        }

        private void BrowseButton_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            if (openFileDialog.ShowDialog() == true)
            {
                InputFileTextBox.Text = openFileDialog.FileName;
            }
        }

        private void RunScriptButton_Click(object sender, RoutedEventArgs e)
        {
            string inputFile = InputFileTextBox.Text;
            if (string.IsNullOrEmpty(inputFile) || !File.Exists(inputFile))
            {
                MessageBox.Show("Please enter a valid file path.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            try
            {
                string invertedFile = InvertBits(inputFile);
                ResultTextBlock.Text = $"Bits inverted. Inverted file saved as: {invertedFile}";
            }
            catch (Exception ex)
            {
                MessageBox.Show($"An error occurred: {ex.Message}", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

        private string InvertBits(string inputFile)
        {
            string directory = Path.GetDirectoryName(inputFile);
            string filename = Path.GetFileName(inputFile);

            byte[] originalData = File.ReadAllBytes(inputFile);
            byte[] invertedData = new byte[originalData.Length];

            for (int i = 0; i < originalData.Length; i++)
            {
                invertedData[i] = (byte)(originalData[i] ^ 0xFF);
            }

            string invertedFile = Path.Combine(directory, "inverse_" + filename);

            File.WriteAllBytes(invertedFile, invertedData);

            return invertedFile;
        }
    }
}
