﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Windows;
using System.Windows.Controls;

namespace ACSuite
{
    public partial class MainWindow : Window
    {
        private readonly Dictionary<string, Type> _windows;

        public MainWindow()
        {
            InitializeComponent();
            _windows = GetWindowTypes();
            PopulateWindowList();
        }

        private Dictionary<string, Type> GetWindowTypes()
        {
            var windowTypes = Assembly.GetExecutingAssembly().GetTypes()
                .Where(t => t.IsSubclassOf(typeof(Window)) && t.Namespace == "ACSuite.Views")
                .ToDictionary(t => t.Name, t => t);
            return windowTypes;
        }

        private void PopulateWindowList()
        {
            foreach (var windowName in _windows.Keys)
            {
                WindowList.Items.Add(windowName);
            }
        }

        private void WindowList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (WindowList.SelectedItem != null)
            {
                var selectedWindowName = WindowList.SelectedItem.ToString();
                if (_windows.TryGetValue(selectedWindowName, out var windowType))
                {
                    var windowInstance = (Window)Activator.CreateInstance(windowType);
                    ContentContainer.Content = windowInstance.Content;
                }
            }
        }
    }
}