﻿using System;
using System.IO;
using System.Linq;
using System.Timers;
using System.Windows;
using System.Windows.Media;

namespace ACSuite.Views
{
    public partial class FileSweeper : Window
    {
        private Timer _timer;
        private bool _isRunning;

        public FileSweeper()
        {
            InitializeComponent();

            string downloadsFolder = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.UserProfile), "Downloads");
            SourceFolderTextBox.Text = downloadsFolder;

            _timer = new Timer(2000); // 2 seconds interval
            _timer.Elapsed += Timer_Elapsed;
        }

        private void StartStopButton_Click(object sender, RoutedEventArgs e)
        {
            if (_isRunning)
            {
                Stop();
            }
            else
            {
                Start();
            }
        }

        private void Start()
        {
            _isRunning = true;
            StartStopButton.Content = "Stop";
            _timer.Start();
            StatusTextBlock.Text = "Monitoring started...";
        }

        private void Stop()
        {
            _isRunning = false;
            StartStopButton.Content = "Start";
            _timer.Stop();
            StatusTextBlock.Text = "Monitoring stopped.";
        }

        private void Timer_Elapsed(object sender, ElapsedEventArgs e)
        {
            Dispatcher.Invoke(() =>
            {
                var extensions = FileExtensionsTextBox.Text
                    .Split(new[] { ',', ' ' }, StringSplitOptions.RemoveEmptyEntries)
                    .Select(ext => ext.Trim());

                foreach (var ext in extensions)
                {
                    var files = Directory.GetFiles(SourceFolderTextBox.Text, $"*{ext}");

                    foreach (var file in files)
                    {
                        try
                        {
                            var destinationPath = Path.Combine(DestinationFolderTextBox.Text, Path.GetFileName(file));
                            File.Move(file, destinationPath);
                            FlashStatus("Successfully moved " + file, Colors.Green);
                        }
                        catch (Exception ex)
                        {
                            FlashStatus("Failed to move " + file + ": " + ex.Message, Colors.Red);
                        }
                    }
                }
            });
        }

        private void FlashStatus(string message, Color color)
        {
            StatusTextBlock.Text = message;
            StatusTextBlock.Background = new SolidColorBrush(color);

            var timer = new Timer(500); // 0.5 second flash
            timer.Elapsed += (s, e) =>
            {
                Dispatcher.Invoke(() =>
                {
                    StatusTextBlock.Background = Brushes.Transparent;
                });
                timer.Stop();
            };
            timer.Start();
        }
    }
}
